import React, { useState, useContext, useEffect } from "react";
import { useCookies } from "react-cookie";
import { useNavigate } from 'react-router-dom';
import classes from "../assets/styles/articles.module.scss"
import MyButton from "../components/MyButton.jsx";
import MyInput from "../components/MyInput.jsx";
import { UserData } from "../context";
import CheckModal from "../components/CheckModal.jsx";
import { createArticleApi, getListArticlesApi } from "../hooks/api/articleApi.js";


const Articles = () => {
    const navigate = useNavigate();
    const {user, setUser} = useContext(UserData);
    const [stateLoading, setStateLoading] = useState(false);

    const [listArticles, setListArticles] = useState([]);

    const [cookies, _, __] = useCookies(["user"]);

    useEffect(() => {
        async function getListArticles() {
            const response = await getListArticlesApi(cookies.token)

            if (response.status === 200) {
                setListArticles(response.data)
            }
        }

        getListArticles()
    }, [])

    async function createArticle() {
        const response = await createArticleApi(cookies.token)

        console.log(response)
        if (response.status === 200) {
            navigate(`/articles/${response.data.id}/edit`)
        }
    }

    return (
        <div className={classes.main}>
            <div className={classes.wrapper}>
                <div className={classes.panel}>
                    <MyInput placeholder={'Поиск...'}/>
                    <MyButton click={createArticle} class={"main__green"} otherStyle={{width: '200px'}} text={
                        stateLoading ? <div class="spinner-border text-light" role="status">
                            <span class="visually-hidden">Загрузка...</span>
                        </div> : 'Создать'
                    }/>
                </div>
                <div className={classes.listArticles}>
                    <div className={classes.listArticles__columns}>
                        <div className={classes.listArticles__columns__item}>Название</div>
                        <div className={classes.listArticles__columns__item}>Дата публикации</div>
                        <div className={classes.listArticles__columns__item}>Автор</div>
                    </div>
                    <div className={classes.listArticles__forms}>
                        {listArticles.map(item => <div className={classes.listArticles__forms__item}>
                            <div className={classes.listArticles__forms__item__title} onClick={() => navigate(`/articles/${item.id}/edit`)}>{item.title}</div>
                            <div className={classes.listArticles__forms__item__date}>24.06.24</div>
                            <div className={classes.listArticles__forms__item__author}>kuwsh1n</div>
                            <i class="fa-solid fa-ellipsis-vertical" id="action" data-bs-toggle="dropdown"></i>
                            <ul class="dropdown-menu" aria-labelledby="action">
                                <li><a class="dropdown-item" onClick={() => navigate(`/articles/${item.id}/`)}>Открыть</a></li>
                                <li><a class="dropdown-item" data-bs-toggle="modal" data-bs-target={`#checkModaltest`}>Удалить</a></li>
                            </ul>

                            <CheckModal 
                                postfix={'test'}
                                message={`Вы хотетите удалить статью <Test article>?`} 
                                action={{
                                    execute: () => {}, 
                                    cancel: () => {}
                                }}
                            />
                        </div>)}
                    </div>
                </div>
            </div>
        </div>
    )
}

export default Articles;