import React, { useState, useEffect } from "react";
import { useNavigate, useParams } from "react-router-dom";
import { useCookies } from "react-cookie";
import classes from "../assets/styles/tokensForm.module.scss";
import { listFormsByTokenApi, newFormTokenApi, removeTokenFormApi } from "../hooks/api/listFormsApi";
import MyButton from "../components/MyButton.jsx";
import MyInput from "../components/MyInput.jsx";
import CheckModal from "../components/CheckModal.jsx";

const TokensForm = () => {
    const { formId } = useParams();
    const [tokens, setTokens] = useState([])
    const [loading, setLoading] = useState(true)
    const [titleToken, setTitleToken] = useState('')

    const [cookies, _, __] = useCookies(["user"]);

    useEffect(() => {
        async function listFormsByToken() {
            const response = await listFormsByTokenApi(cookies.token, formId)
            console.log(response)
            
            if (response.data.tokens) {
                setTokens(response.data.tokens.filter(item => item.is_active === true))
                setLoading(false)
            }
            else {
                console.log(response)
            }
        }

        listFormsByToken()
    }, [])

    async function newFormToken() {
        const response = await newFormTokenApi(cookies.token, formId)

        if (response.status === 200) {
            setTokens([...tokens, response.data.token])
        }
        else {
            console.log(response)
        }
    }

    async function removeTokenForm(tokenForm) {
        const response = await removeTokenFormApi(cookies.token, formId, tokenForm)

        if (response.status === 200) {
            setTokens(tokens.filter(item => item.id !== tokenForm))
        }
        else {
            console.log(response)
        }
    }

    return (
        <div className={classes.main}>
            <div className={classes.wrapper}>
                <div className={classes.answers}>
                    <div className={classes.answers__wrapper}>
                        <div className={classes.answers__wrapper__header}>
                            <h3>Токены формы</h3>
                            <MyButton text={"Создать"} class={"main__green"} click={newFormToken}/>
                        </div>
                        <div className={classes.answers__wrapper__body}>
                            <div className={classes.answers__wrapper__body__column}>
                                <div className={classes.answers__wrapper__body__column__wrapper}>
                                    <div>Название</div>
                                    <div>Токен</div>
                                </div>
                            </div>

                            {tokens ? 
                                tokens.map((item, i) => 
                                    <div className={classes.answers__wrapper__body__item} key={i}>
                                        <div className={classes.answers__wrapper__body__item__wrapper}>
                                            <div className={classes.answers__wrapper__body__item__wrapper__title}>
                                                По умолчанию
                                            </div>
                                            <div className={classes.answers__wrapper__body__item__wrapper__token}>
                                                {item.id}
                                            </div>
                                        </div>
                                        <div className={classes.answers__wrapper__body__item__btn}>
                                            <i 
                                                class="fa-solid fa-pen" 
                                                data-bs-toggle="modal" 
                                                data-bs-target={`#tokensModal${i}`} 
                                                onClick={() => setTitleToken("По умолчанию")}>
                                            </i>
                                            <i class="fa-solid fa-trash" onClick={() => removeTokenForm(item.id)}></i>
                                        </div>
                                        

                                        <div class="modal fade myModal" className={classes.myModal} id={`tokensModal${i}`} tabIndex="-1" aria-labelledby="exampleModalLabel" data-bs-backdrop="static" aria-hidden="true">
                                            <div class="modal-dialog myModal__dialog" className={classes.myModal__dialog}>
                                                <div class="modal-content" className={classes.myModal__dialog__content}>
                                                    <div class="modal-body" className={classes.myModal__dialog__content__body}>
                                                        <MyInput type={"text"} value={titleToken} change={setTitleToken}/>
                                                    </div>
                                                    <div class="modal-footer myModal__dialog__content__footer" className={classes.myModal__dialog__content__footer}>
                                                        <MyButton text={"Сохранить"} class={"main__green"} dismiss={"modal"}/>
                                                        <MyButton text={"Отмена"} class={"main__white"} dismiss={"modal"}/>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                )
                            : 
                            <div className={classes.loading__wrapper}>
                                <div class="spinner-border text-dark" className={classes.loading__wrapper__body} role="status">
                                    <span class="visually-hidden">Загрузка...</span>
                                </div>
                            </div>}
                        </div>                        
                    </div>
                </div>
            </div>
        </div>
    )
}

export default TokensForm;