import React, { useState, useContext, useEffect, useLocation } from "react";
import { useNavigate, useParams } from "react-router-dom";
import { useCookies } from "react-cookie";
import classes from "../assets/styles/viewArticle.module.scss";
import { FormsData, TypeAnswerData, answersData, UserData } from "../context";
import MyButton from "../components/MyButton.jsx";
import { getArticleApi } from "../hooks/api/articleApi.js";
import { getListUserApi } from "../hooks/api/profileApi.js";


const ViewArticle = () => {
    const navigate = useNavigate();
    // const location = useLocation();
    const { articleId } = useParams();

    const [title, setTitle] = useState("");
    const [tags, setTags] = useState([]);
    const [newTag, setNewTag] = useState("")
    const [owner, setOwner] = useState("");

    const [contentArticle, setContentArticle] = useState('');

    const [cookies, _, __] = useCookies(["user"]);

    useEffect(() => {
        async function getArticle() {
            const response = await getArticleApi(cookies.token, articleId)
            const user = await getListUserApi(cookies.token)

            if (response.status === 200) {
                console.log(response)
                setTitle(response.data.article.title)
                setTags(response.data.article.tags ? response.data.article.tags : [])
                setOwner(user.status === 200 ? user.data.find(item => item.id === response.data.article.owner_id).login : response.data.article.owner_id)
                setContentArticle(response.data.blocks ? response.data.blocks[0].data : '')
            }
        }

        getArticle()
    }, [])

    return (
        <div className={classes.main}>
            <div className={classes.wrapper}>
                <div className={classes.header}>
                    <div className={classes.header__wrapper}>
                        <div className={classes.header__wrapper__article}>
                            <div className={classes.header__wrapper__article__title}>
                                <span className={classes.header__wrapper__article__title__name}>Название</span>
                                <span className={classes.header__wrapper__article__title__text}>{title}</span>
                            </div>
                            <div className={classes.header__wrapper__article__tags}>
                                {/* <span className={classes.header__wrapper__article__tags__name}>Тэги</span> */}
                                {tags.map(item => <div className={classes.header__wrapper__tags__item}>
                                    <span>#{item}</span>
                                </div>)}
                            </div>
                            <div className={classes.header__wrapper__article__owner}>
                                <span className={classes.header__wrapper__article__owner__name}>Автор</span>
                                <span className={classes.header__wrapper__article__owner__text}>{owner}</span>
                            </div>
                        </div>
                    </div>
                </div>
                <div className={classes.content}>
                    <div className={classes.content__wrapper}>
                        <div className="classes.content__wrapper__article" dangerouslySetInnerHTML={{__html: contentArticle}}>

                        </div>
                    </div>
                </div>
            </div>
        </div>
    )
}


export default ViewArticle